@@ -32,7 +32,7 @@ impl Users {
      * * `sort_order: crate::types::SortOrder` -- Whether to return results in ascending or descending order. Must be used with the `orderBy` parameter.
      * * `view_type: crate::types::ViewType` -- Whether to fetch the administrator-only or domain-wide public view of the user. For more information, see [Retrieve a user as a non-administrator](/admin-sdk/directory/v1/guides/manage-users#retrieve_users_non_admin).
      */
-    pub async fn directory_list(
+    pub async fn list(
         &self,
         customer: &str,
         domain: &str,
@@ -83,7 +83,7 @@ impl Users {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!("/admin/directory/v1/users?{}", query_);
 
-        let resp: crate::types::Users = self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::Users = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.users)
@@ -92,11 +92,11 @@ impl Users {
     /**
      * This function performs a `GET` to the `/admin/directory/v1/users` endpoint.
      *
-     * As opposed to `directory_list`, this function returns all the pages of the request at once.
+     * As opposed to `list`, this function returns all the pages of the request at once.
      *
      * Retrieves a paginated list of either deleted users or all users in a domain.
      */
-    pub async fn directory_list_users(
+    pub async fn list_all(
         &self,
         customer: &str,
         domain: &str,
@@ -139,7 +139,7 @@ impl Users {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!("/admin/directory/v1/users?{}", query_);
 
-        let mut resp: crate::types::Users = self.client.get(&url, None).await.unwrap();
+        let mut resp: crate::types::Users = self.client.get(&url, None).await?;
 
         let mut users = resp.users;
         let mut page = resp.next_page_token;
@@ -150,14 +150,12 @@ impl Users {
                 resp = self
                     .client
                     .get(&format!("{}?pageToken={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&pageToken={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             users.append(&mut resp.users);
@@ -178,13 +176,10 @@ impl Users {
      *
      * Creates a user.
      */
-    pub async fn directory_insert(&self, body: &crate::types::User) -> Result<crate::types::User> {
+    pub async fn insert(&self, body: &crate::types::User) -> Result<crate::types::User> {
         let url = "/admin/directory/v1/users".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -208,7 +203,7 @@ impl Users {
      * * `sort_order: crate::types::SortOrder` -- Whether to return results in ascending or descending order. Must be used with the `orderBy` parameter.
      * * `view_type: crate::types::ViewType` -- Whether to fetch the administrator-only or domain-wide public view of the user. For more information, see [Retrieve a user as a non-administrator](/admin-sdk/directory/v1/guides/manage-users#retrieve_users_non_admin).
      */
-    pub async fn directory_watch(
+    pub async fn watch(
         &self,
         customer: &str,
         domain: &str,
@@ -261,10 +256,7 @@ impl Users {
         let url = format!("/admin/directory/v1/users/watch?{}", query_);
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -280,7 +272,7 @@ impl Users {
      * * `projection: crate::types::DirectoryUsersListProjection` -- What subset of fields to fetch for this user.
      * * `view_type: crate::types::ViewType` -- Whether to fetch the administrator-only or domain-wide public view of the user. For more information, see [Retrieve a user as a non-administrator](/admin-sdk/directory/v1/guides/manage-users#retrieve_users_non_admin).
      */
-    pub async fn directory_get(
+    pub async fn get(
         &self,
         user_key: &str,
         projection: crate::types::DirectoryUsersListProjection,
@@ -312,7 +304,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_update(
+    pub async fn update(
         &self,
         user_key: &str,
         body: &crate::types::User,
@@ -323,10 +315,7 @@ impl Users {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -339,7 +328,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_delete(&self, user_key: &str) -> Result<()> {
+    pub async fn delete(&self, user_key: &str) -> Result<()> {
         let url = format!(
             "/admin/directory/v1/users/{}",
             crate::progenitor_support::encode_path(&user_key.to_string()),
@@ -357,7 +346,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_patch(
+    pub async fn patch(
         &self,
         user_key: &str,
         body: &crate::types::User,
@@ -368,10 +357,7 @@ impl Users {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -385,7 +371,7 @@ impl Users {
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      * * `event: crate::types::DirectoryUsersAliasesListEvent` -- Events to watch for.
      */
-    pub async fn directory_aliases_list(
+    pub async fn aliases_list(
         &self,
         user_key: &str,
         event: crate::types::DirectoryUsersAliasesListEvent,
@@ -413,7 +399,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_aliases_insert(
+    pub async fn aliases_insert(
         &self,
         user_key: &str,
         body: &crate::types::Alias,
@@ -424,10 +410,7 @@ impl Users {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -441,7 +424,7 @@ impl Users {
      * * `user_key: &str` -- Email or immutable ID of the user.
      * * `event: crate::types::DirectoryUsersAliasesListEvent` -- Events to watch for.
      */
-    pub async fn directory_aliases_watch(
+    pub async fn aliases_watch(
         &self,
         user_key: &str,
         event: crate::types::DirectoryUsersAliasesListEvent,
@@ -459,10 +442,7 @@ impl Users {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -476,7 +456,7 @@ impl Users {
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      * * `alias: &str` -- The alias to be removed.
      */
-    pub async fn directory_aliases_delete(&self, user_key: &str, alias: &str) -> Result<()> {
+    pub async fn aliases_delete(&self, user_key: &str, alias: &str) -> Result<()> {
         let url = format!(
             "/admin/directory/v1/users/{}/aliases/{}",
             crate::progenitor_support::encode_path(&user_key.to_string()),
@@ -495,7 +475,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_make_admin(
+    pub async fn make_admin(
         &self,
         user_key: &str,
         body: &crate::types::UserMakeAdmin,
@@ -506,10 +486,7 @@ impl Users {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -522,7 +499,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_photos_get(&self, user_key: &str) -> Result<crate::types::UserPhoto> {
+    pub async fn photos_get(&self, user_key: &str) -> Result<crate::types::UserPhoto> {
         let url = format!(
             "/admin/directory/v1/users/{}/photos/thumbnail",
             crate::progenitor_support::encode_path(&user_key.to_string()),
@@ -540,7 +517,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_photos_update(
+    pub async fn photos_update(
         &self,
         user_key: &str,
         body: &crate::types::UserPhoto,
@@ -551,10 +528,7 @@ impl Users {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -567,7 +541,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_photos_delete(&self, user_key: &str) -> Result<()> {
+    pub async fn photos_delete(&self, user_key: &str) -> Result<()> {
         let url = format!(
             "/admin/directory/v1/users/{}/photos/thumbnail",
             crate::progenitor_support::encode_path(&user_key.to_string()),
@@ -585,7 +559,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_photos_patch(
+    pub async fn photos_patch(
         &self,
         user_key: &str,
         body: &crate::types::UserPhoto,
@@ -596,10 +570,7 @@ impl Users {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -612,7 +583,7 @@ impl Users {
      *
      * * `user_key: &str` -- Identifies the target user in the API request. The value can be the user's primary email address, alias email address, or unique user ID.
      */
-    pub async fn directory_sign_out(&self, user_key: &str) -> Result<()> {
+    pub async fn sign_out(&self, user_key: &str) -> Result<()> {
         let url = format!(
             "/admin/directory/v1/users/{}/signOut",
             crate::progenitor_support::encode_path(&user_key.to_string()),
@@ -630,21 +601,14 @@ impl Users {
      *
      * * `user_key: &str` -- The immutable id of the user.
      */
-    pub async fn directory_undelete(
-        &self,
-        user_key: &str,
-        body: &crate::types::UserUndelete,
-    ) -> Result<()> {
+    pub async fn undelete(&self, user_key: &str, body: &crate::types::UserUndelete) -> Result<()> {
         let url = format!(
             "/admin/directory/v1/users/{}/undelete",
             crate::progenitor_support::encode_path(&user_key.to_string()),
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
